##  Field Width
Field width, ranging from XS to XXL, helps align fields on the fact sheet page. This T-shirt sizing analogy is used for easy understanding and comparison. The number indicated in brackets corresponds to the column width occupied by the field.
The following images show how fields of the String type with different display options appear on a fact sheet:
  * Field of the String type displayed as Text area
![Width of a String Field Displayed as Text Area](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2754458a7a4410149ea68f100e5d092d_LowRes.png)
Width of a String Field Displayed as Text Area
  * Field of the String type displayed as Text
![Width of a String Displayed as Text](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274775137a441014b416c20412164dda_LowRes.png)
Width of a String Displayed as Text


**Note**
There's no character limit associated with the field width. However, fields containing more than 32,766 characters may lead to incorrect behavior in your workspace, so it's important to monitor content length for optimal performance.
